import Whisper
from enum import Enum
from typing import Union
from pathlib import Path

LANGUAGE = "english"

class MODEL(str, Enum):
    tiny = "tiny",
    base = "base",
    small = "small",
    medium = "medium",
    large = "large"

    def __str__(self) -> str:
        return self.value

class MODEL_EN(str, Enum):
    tiny = "tiny.en",
    base = "base.en",
    small = "small.en",
    medium = "medium.en"

    def __str__(self) -> str:
        return self.value

def recognize(model: Union[MODEL, MODEL_EN], audio: Path, language=LANGUAGE):
    mod = Whisper.load_model(model)

    ## audio = Whisper.load_audio("audio.mp3")

    options = Whisper.DecodingOptions()
    result = mod.transcribe(audio)

    print(result.text)
# print the recognized text



from setuptools import setup, find_packages

VERSION = '0.0.1.23'
DESCRIPTION = 'Whisper package'
LONG_DESCRIPTION = 'A package that allows easily to use the Whisper library'

# Setting up
setup(
    name="whisp",
    version=VERSION,
    author="Peteris N.",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['setuptools-rust'],
    keywords=[],
    classifiers=[]
)